require 'mocha/version'
require 'mocha_standalone'
require 'mocha/configuration'
require 'mocha/integration'
